==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/GitRepoVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface GitRepoVolumeSourceFluent<A extends GitRepoVolumeSourceFluent<A>> extends Fluent<A> {


    public String getDirectory();
    public A withDirectory(String directory);
    public Boolean hasDirectory();
    public A withNewDirectory(StringBuilder arg1);
    public A withNewDirectory(int[] arg1,int arg2,int arg3);
    public A withNewDirectory(char[] arg1);
    public A withNewDirectory(StringBuffer arg1);
    public A withNewDirectory(byte[] arg1,int arg2);
    public A withNewDirectory(byte[] arg1);
    public A withNewDirectory(char[] arg1,int arg2,int arg3);
    public A withNewDirectory(byte[] arg1,int arg2,int arg3);
    public A withNewDirectory(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDirectory(String arg1);
    public String getRepository();
    public A withRepository(String repository);
    public Boolean hasRepository();
    public A withNewRepository(StringBuilder arg1);
    public A withNewRepository(int[] arg1,int arg2,int arg3);
    public A withNewRepository(char[] arg1);
    public A withNewRepository(StringBuffer arg1);
    public A withNewRepository(byte[] arg1,int arg2);
    public A withNewRepository(byte[] arg1);
    public A withNewRepository(char[] arg1,int arg2,int arg3);
    public A withNewRepository(byte[] arg1,int arg2,int arg3);
    public A withNewRepository(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRepository(String arg1);
    public String getRevision();
    public A withRevision(String revision);
    public Boolean hasRevision();
    public A withNewRevision(StringBuilder arg1);
    public A withNewRevision(int[] arg1,int arg2,int arg3);
    public A withNewRevision(char[] arg1);
    public A withNewRevision(StringBuffer arg1);
    public A withNewRevision(byte[] arg1,int arg2);
    public A withNewRevision(byte[] arg1);
    public A withNewRevision(char[] arg1,int arg2,int arg3);
    public A withNewRevision(byte[] arg1,int arg2,int arg3);
    public A withNewRevision(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRevision(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/GitRepoVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface GitRepoVolumeSourceFluent<A extends GitRepoVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getDirectory();
    public A withDirectory(String directory);
    public Boolean hasDirectory();
    public A withNewDirectory(StringBuilder arg1);
    public A withNewDirectory(int[] arg1,int arg2,int arg3);
    public A withNewDirectory(char[] arg1);
    public A withNewDirectory(StringBuffer arg1);
    public A withNewDirectory(byte[] arg1,int arg2);
    public A withNewDirectory(byte[] arg1);
    public A withNewDirectory(char[] arg1,int arg2,int arg3);
    public A withNewDirectory(byte[] arg1,int arg2,int arg3);
    public A withNewDirectory(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDirectory(String arg1);
    public String getRepository();
    public A withRepository(String repository);
    public Boolean hasRepository();
    public A withNewRepository(StringBuilder arg1);
    public A withNewRepository(int[] arg1,int arg2,int arg3);
    public A withNewRepository(char[] arg1);
    public A withNewRepository(StringBuffer arg1);
    public A withNewRepository(byte[] arg1,int arg2);
    public A withNewRepository(byte[] arg1);
    public A withNewRepository(char[] arg1,int arg2,int arg3);
    public A withNewRepository(byte[] arg1,int arg2,int arg3);
    public A withNewRepository(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRepository(String arg1);
    public String getRevision();
    public A withRevision(String revision);
    public Boolean hasRevision();
    public A withNewRevision(StringBuilder arg1);
    public A withNewRevision(int[] arg1,int arg2,int arg3);
    public A withNewRevision(char[] arg1);
    public A withNewRevision(StringBuffer arg1);
    public A withNewRevision(byte[] arg1,int arg2);
    public A withNewRevision(byte[] arg1);
    public A withNewRevision(char[] arg1,int arg2,int arg3);
    public A withNewRevision(byte[] arg1,int arg2,int arg3);
    public A withNewRevision(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRevision(String arg1);
}
